==> heroes-0.0.1.tar.gz: lib/src/nearby_connections_service/nearby_connections_proximity_detection.dart <==
import '../detection_service/detection_service.dart';
import '../iproximitydetection/iproximitydetection.dart';
import 'nearby_connections_service.dart';

class NearbyConnectionsProximityDetection implements IProximityDetection
{
  static final _instance = NearbyConnectionsProximityDetection._internal();
  factory NearbyConnectionsProximityDetection() => _instance;
  NearbyConnectionsProximityDetection._internal()
  {
    _nearbyConnectionsService = NearbyConnectionsService();

    _nearbyConnectionsService.onDetectedCallback = onDetected;
    _nearbyConnectionsService.onLostCallback = onLost;
  }

  set detectionService(DetectionService detectionService) => _detectionService = detectionService;
  DetectionService _detectionService = DetectionService();
  NearbyConnectionsService _nearbyConnectionsService;

  Map<String, String> _endPointsFoundMap = new Map<String, String>();
  Map<String, DateTime> __endPointsFoundTimesMap = new Map<String, DateTime>();

  //String id, String name
  @override
  void onDetected(detected)
  {
    print("HEROES_FLUTTER_PLUGIN :: NearbyConnectionsProximityDetection :: onDetected(): ");

    final id = detected["id"];
    final name = detected["name"];

    print(detected.toString());

    String lastIdForThisName = id;
    MapEntry<String, String> mapEntry = MapEntry(id, name);
    List<MapEntry<String, String>> mapEntryList = List<MapEntry<String, String>>();
    mapEntryList.add(mapEntry);

    for (var entry in _endPointsFoundMap.entries) {
      if (entry.value == name)
        lastIdForThisName = entry.key;
    }

    if (lastIdForThisName != id) {
      _endPointsFoundMap.remove(lastIdForThisName);
      __endPointsFoundTimesMap.remove(lastIdForThisName);
    }

    if (!_endPointsFoundMap.containsKey(id))
      _endPointsFoundMap.addEntries(mapEntryList);

    if (!__endPointsFoundTimesMap.containsKey(id)) {
      MapEntry<String, DateTime> mapTimeEntry = MapEntry(id, DateTime.now());
      List<MapEntry<String, DateTime>> mapTimeEntryList = List<MapEntry<String, DateTime>>();
      mapTimeEntryList.add(mapTimeEntry);
      __endPointsFoundTimesMap.addEntries(mapTimeEntryList);
    }

    _detectionService.startEncounter(name, DateTime.now());
  }

  @override
  void onLost(lost)
  {
    final id = lost["id"];

    if (_endPointsFoundMap.containsKey(id)) {
      _detectionService.endEncounter(_endPointsFoundMap[id]);
      __endPointsFoundTimesMap.remove(id);
      _endPointsFoundMap.remove(id);
    }
  }

  @override
  Future<void> startScanning([params]) async
  {
    await NearbyConnectionsService().init();
    return null;
  }

  @override
  Future<void> stopScanning([params]) async
  {
    await NearbyConnectionsService().stop();
    return null;
  }
}

==> heroes-0.1.0.tar.gz: lib/src/nearby_connections_service/nearby_connections_proximity_detection.dart <==
import '../detection_service/detection_service.dart';
import '../iproximitydetection/iproximitydetection.dart';
import 'nearby_connections_service.dart';

class NearbyConnectionsProximityDetection implements IProximityDetection
{
  //static final _instance = NearbyConnectionsProximityDetection._internal();
  //factory NearbyConnectionsProximityDetection() => _instance;
  NearbyConnectionsProximityDetection()//._internal()
  {
    _nearbyConnectionsService = NearbyConnectionsService();

    _nearbyConnectionsService.onDetectedCallback = onDetected;
    _nearbyConnectionsService.onLostCallback = onLost;
  }

  set detectionService(DetectionService detectionService) => _detectionService = detectionService;
  DetectionService _detectionService = DetectionService();
  NearbyConnectionsService _nearbyConnectionsService;

  Map<String, String> _endPointsFoundMap = new Map<String, String>();
  Map<String, DateTime> __endPointsFoundTimesMap = new Map<String, DateTime>();

  //String id, String name
  @override
  void onDetected(detected)
  {
    print("HEROES_FLUTTER_PLUGIN :: NearbyConnectionsProximityDetection :: onDetected(): ");

    final id = detected["id"];
    final name = detected["name"];

    print(detected.toString());

    String lastIdForThisName = id;
    MapEntry<String, String> mapEntry = MapEntry(id, name);
    List<MapEntry<String, String>> mapEntryList = List<MapEntry<String, String>>();
    mapEntryList.add(mapEntry);

    for (var entry in _endPointsFoundMap.entries) {
      if (entry.value == name)
        lastIdForThisName = entry.key;
    }

    if (lastIdForThisName != id) {
      _endPointsFoundMap.remove(lastIdForThisName);
      __endPointsFoundTimesMap.remove(lastIdForThisName);
    }

    if (!_endPointsFoundMap.containsKey(id))
      _endPointsFoundMap.addEntries(mapEntryList);

    if (!__endPointsFoundTimesMap.containsKey(id)) {
      MapEntry<String, DateTime> mapTimeEntry = MapEntry(id, DateTime.now());
      List<MapEntry<String, DateTime>> mapTimeEntryList = List<MapEntry<String, DateTime>>();
      mapTimeEntryList.add(mapTimeEntry);
      __endPointsFoundTimesMap.addEntries(mapTimeEntryList);
    }

    if (onDetectedCallback != null)
      onDetectedCallback(name, DateTime.now());
  }

  @override
  void onLost(lost)
  {
    final id = lost["id"];

    if (_endPointsFoundMap.containsKey(id)) {
      if (onLostCallback != null)
        onLostCallback(_endPointsFoundMap[id]);
      __endPointsFoundTimesMap.remove(id);
      _endPointsFoundMap.remove(id);
    }
  }

  @override
  Future<void> startScanning([params]) async
  {
    await NearbyConnectionsService().init();
    return null;
  }

  @override
  Future<void> stopScanning([params]) async
  {
    await NearbyConnectionsService().stop();
    return null;
  }

  @override
  Function onDetectedCallback;

  @override
  Function onLostCallback;
}
